@@ -32,4 +32,7 @@ pub enum ContractError {
 
     #[error("Unauthorized")]
     Unauthorized {},
+
+    #[error("Swap Details not found")]
+    SwapDetailsNotFound
 }
\ No newline at end of file
